[git commit] script: make -t[FILE] compatible with util-linux

Denys Vlasenko vda.linux at googlemail.com
Mon Aug 7 00:12:36 UTC 2017


commit: https://git.busybox.net/busybox/commit/?id=269b36a49a60a90ce59dd6209728ec97fd72077e
branch: https://git.busybox.net/busybox/commit/?id=refs/heads/master

function                                             old     new   delta
script_main                                         1056    1102     +46
packed_usage                                       31736   31765     +29
------------------------------------------------------------------------------
(add/remove: 0/0 grow/shrink: 2/0 up/down: 75/0)               Total: 75 bytes

Signed-off-by: Denys Vlasenko <vda.linux at googlemail.com>
---
 editors/sed.c       |  4 ++--
 util-linux/script.c | 22 +++++++++++++++-------
 2 files changed, 17 insertions(+), 9 deletions(-)

diff --git a/editors/sed.c b/editors/sed.c
index bec2004..22580cf 100644
--- a/editors/sed.c
+++ b/editors/sed.c
@@ -68,8 +68,8 @@
 //applet:IF_SED(APPLET(sed, BB_DIR_BIN, BB_SUID_DROP))
 
 //usage:#define sed_trivial_usage
-//usage:       "[-inrE] [-f FILE]... [-e CMD]... [FILE]...\n"
-//usage:       "or: sed [-inrE] CMD [FILE]..."
+//usage:       "[-i[SFX]] [-nrE] [-f FILE]... [-e CMD]... [FILE]...\n"
+//usage:       "or: sed [-i[SFX]] [-nrE] CMD [FILE]..."
 //usage:#define sed_full_usage "\n\n"
 //usage:       "	-e CMD	Add CMD to sed commands to be executed"
 //usage:     "\n	-f FILE	Add FILE contents to sed commands to be executed"
diff --git a/util-linux/script.c b/util-linux/script.c
index 6e80943..62a2417 100644
--- a/util-linux/script.c
+++ b/util-linux/script.c
@@ -21,16 +21,17 @@
 //kbuild:lib-$(CONFIG_SCRIPT) += script.o
 
 //usage:#define script_trivial_usage
-//usage:       "[-afqt] [-c PROG] [OUTFILE]"
+//usage:       "[-afq] [-t[FILE]] [-c PROG] [OUTFILE]"
 //usage:#define script_full_usage "\n\n"
-//usage:       "	-a	Append output"
+//usage:       "Default OUTFILE is 'typescript'"
+//usage:     "\n"
+//usage:     "\n	-a	Append output"
 //usage:     "\n	-c PROG	Run PROG, not shell"
 //usage:     "\n	-f	Flush output after each write"
 //usage:     "\n	-q	Quiet"
 //usage:     "\n	-t	Send timing to stderr"
 
 //util-linux-2.28:
-//-t[FILE]
 //-e: return exit code of the child
 
 //FYI (reported as bbox bug #2749):
@@ -54,6 +55,8 @@ int script_main(int argc UNUSED_PARAM, char **argv)
 	char pty_line[GETPTY_BUFSIZE];
 	struct termios tt, rtt;
 	struct winsize win;
+	FILE *timing_fp;
+	const char *str_t = NULL;
 	const char *fname = "typescript";
 	const char *shell;
 	char shell_opt[] = "-i";
@@ -72,14 +75,14 @@ int script_main(int argc UNUSED_PARAM, char **argv)
 		"command\0" Required_argument "c"
 		"flush\0"   No_argument       "f"
 		"quiet\0"   No_argument       "q"
-		"timing\0"  No_argument       "t"
+		"timing\0"  Optional_argument "t"
 		;
 
 	applet_long_options = getopt_longopts;
 #endif
 
 	opt_complementary = "?1"; /* max one arg */
-	opt = getopt32(argv, "ac:fqt", &shell_arg);
+	opt = getopt32(argv, "ac:fqt::", &shell_arg, &str_t);
 	//argc -= optind;
 	argv += optind;
 	if (argv[0]) {
@@ -95,6 +98,10 @@ int script_main(int argc UNUSED_PARAM, char **argv)
 	if (!(opt & OPT_q)) {
 		printf("Script started, file is %s\n", fname);
 	}
+	timing_fp = stderr;
+	if (str_t) {
+		timing_fp = xfopen_for_write(str_t);
+	}
 
 	shell = get_shell_name();
 
@@ -130,6 +137,7 @@ int script_main(int argc UNUSED_PARAM, char **argv)
 		int outfd, count, loop;
 		double oldtime = time(NULL);
 		smallint fd_count = 2;
+
 #define buf bb_common_bufsiz1
 		setup_common_bufsiz();
 
@@ -165,7 +173,7 @@ int script_main(int argc UNUSED_PARAM, char **argv)
 
 						gettimeofday(&tv, NULL);
 						newtime = tv.tv_sec + (double) tv.tv_usec / 1000000;
-						fprintf(stderr, "%f %u\n", newtime - oldtime, count);
+						fprintf(timing_fp, "%f %u\n", newtime - oldtime, count);
 						oldtime = newtime;
 					}
 					full_write(STDOUT_FILENO, buf, count);
@@ -21,16 +21,17 @@
 //usage:     "\n	-f	Flush output after each write"
 //usage:     "\n	-q	Quiet"
-//usage:     "\n	-t	Send timing to stderr"
+//usage:     "\n	-t[FILE] Send timing to stderr or FILE"
 
 //util-linux-2.28:


More information about the busybox-cvs mailing list